@@ -23,12 +23,15 @@ class HappyDiffer(difflib.Differ):
 
     def _dump(self, tag, x, lo, hi):
         if tag == '+':
-            tag = "Yours: "
+            tag = "Mine: "
         elif tag == '-':
-            tag = "Mine:  "
+            tag = "Yours:  "
         elif tag == ' ':
-            tag = "Ours : "
+            tag = "Ours: "
         for i in range(lo, hi):
+            if x[i] == '\n':
+                yield '%s %s' % (tag, "(newline)")
+                continue
             yield '%s %s' % (tag, x[i])
 
 
@@ -112,8 +115,8 @@ class GoldenTestCase(UCTestCase):
         print("Below is an explanation of how your program's output differs from the\nexpected output.")
         print((":" * 80))
         print("\n".join(HappyDiffer().compare(
-            actual.split("\n"),
-            golden.split("\n"))))
+            [ x + "\n" for x in actual.split("\n")],
+            [ x + "\n" for x in golden.split("\n")])))
 
     # Test Cases
     def student_view(self):
